==> core_models-0.1.0.gem: app/controllers/core_models/people_and_companies/company_bank_accounts_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class PeopleAndCompanies::CompanyBankAccountsController < CoreModelsController
    # GET /people_and_companies/company_bank_accounts
    # GET /people_and_companies/company_bank_accounts.json
    def index
      @people_and_companies_company_bank_accounts = PeopleAndCompanies::CompanyBankAccount.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @people_and_companies_company_bank_accounts }
      end
    end

    # GET /people_and_companies/company_bank_accounts/1
    # GET /people_and_companies/company_bank_accounts/1.json
    def show
      @people_and_companies_company_bank_account = PeopleAndCompanies::CompanyBankAccount.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @people_and_companies_company_bank_account }
      end
    end

    # GET /people_and_companies/company_bank_accounts/new
    # GET /people_and_companies/company_bank_accounts/new.json
    def new
      @people_and_companies_company_bank_account = PeopleAndCompanies::CompanyBankAccount.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @people_and_companies_company_bank_account }
      end
    end

    # GET /people_and_companies/company_bank_accounts/1/edit
    def edit
      @people_and_companies_company_bank_account = PeopleAndCompanies::CompanyBankAccount.find(params[:id])
    end

    # POST /people_and_companies/company_bank_accounts
    # POST /people_and_companies/company_bank_accounts.json
    def create
      @people_and_companies_company_bank_account = PeopleAndCompanies::CompanyBankAccount.new(params[:people_and_companies_company_bank_account])

      respond_to do |format|
        if @people_and_companies_company_bank_account.save
          format.html { redirect_to @people_and_companies_company_bank_account, :notice => 'Company bank account was successfully created.' }
          format.json { render :json => @people_and_companies_company_bank_account, :status => :created, :location => @people_and_companies_company_bank_account }
        else
          format.html { render :action => "new" }
          format.json { render :json => @people_and_companies_company_bank_account.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /people_and_companies/company_bank_accounts/1
    # PUT /people_and_companies/company_bank_accounts/1.json
    def update
      @people_and_companies_company_bank_account = PeopleAndCompanies::CompanyBankAccount.find(params[:id])

      respond_to do |format|
        if @people_and_companies_company_bank_account.update_attributes(params[:people_and_companies_company_bank_account])
          format.html { redirect_to @people_and_companies_company_bank_account, :notice => 'Company bank account was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @people_and_companies_company_bank_account.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /people_and_companies/company_bank_accounts/1
    # DELETE /people_and_companies/company_bank_accounts/1.json
    def destroy
      @people_and_companies_company_bank_account = PeopleAndCompanies::CompanyBankAccount.find(params[:id])
      @people_and_companies_company_bank_account.destroy

      respond_to do |format|
        format.html { redirect_to people_and_companies_company_bank_accounts_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/people_and_companies/company_bank_accounts_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class PeopleAndCompanies::CompanyBankAccountsController < CoreModelsController
    # GET /people_and_companies/company_bank_accounts
    # GET /people_and_companies/company_bank_accounts.json
    def index
      @people_and_companies_company_bank_accounts = PeopleAndCompanies::CompanyBankAccount.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @people_and_companies_company_bank_accounts }
      end
    end

    # GET /people_and_companies/company_bank_accounts/1
    # GET /people_and_companies/company_bank_accounts/1.json
    def show
      @people_and_companies_company_bank_account = PeopleAndCompanies::CompanyBankAccount.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @people_and_companies_company_bank_account }
      end
    end

    # GET /people_and_companies/company_bank_accounts/new
    # GET /people_and_companies/company_bank_accounts/new.json
    def new
      @people_and_companies_company_bank_account = PeopleAndCompanies::CompanyBankAccount.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @people_and_companies_company_bank_account }
      end
    end

    # GET /people_and_companies/company_bank_accounts/1/edit
    def edit
      @people_and_companies_company_bank_account = PeopleAndCompanies::CompanyBankAccount.find(params[:id])
    end

    # POST /people_and_companies/company_bank_accounts
    # POST /people_and_companies/company_bank_accounts.json
    def create
      @people_and_companies_company_bank_account = PeopleAndCompanies::CompanyBankAccount.new(params[:people_and_companies_company_bank_account])

      respond_to do |format|
        if @people_and_companies_company_bank_account.save
          format.html { redirect_to @people_and_companies_company_bank_account, :notice => 'Company bank account was successfully created.' }
          format.json { render :json => @people_and_companies_company_bank_account, :status => :created, :location => @people_and_companies_company_bank_account }
        else
          format.html { render :action => "new" }
          format.json { render :json => @people_and_companies_company_bank_account.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /people_and_companies/company_bank_accounts/1
    # PUT /people_and_companies/company_bank_accounts/1.json
    def update
      @people_and_companies_company_bank_account = PeopleAndCompanies::CompanyBankAccount.find(params[:id])

      respond_to do |format|
        if @people_and_companies_company_bank_account.update(params[:people_and_companies_company_bank_account])
          format.html { redirect_to @people_and_companies_company_bank_account, :notice => 'Company bank account was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @people_and_companies_company_bank_account.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /people_and_companies/company_bank_accounts/1
    # DELETE /people_and_companies/company_bank_accounts/1.json
    def destroy
      @people_and_companies_company_bank_account = PeopleAndCompanies::CompanyBankAccount.find(params[:id])
      @people_and_companies_company_bank_account.destroy

      respond_to do |format|
        format.html { redirect_to people_and_companies_company_bank_accounts_url }
        format.json { head :no_content }
      end
    end
  end
end
